@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Utilities;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Internal utilities for JSON::Schema::Modern
 
-our $VERSION = '0.536';
+our $VERSION = '0.537';
 
 use 5.020;
 use strictures 2;
@@ -77,13 +77,12 @@ sub is_type ($type, $value) {
 
     if ($type eq 'number') {
       return ref($value) =~ /^Math::Big(?:Int|Float)$/
-        || !($flags & B::SVf_POK) && ($flags & (B::SVf_IOK | B::SVf_NOK))
+        || !($flags & B::SVf_POK) && ($flags & (B::SVf_IOK | B::SVf_NOK));
     }
 
     if ($type eq 'integer') {
-      return (ref($value) =~ /^Math::Big(?:Int|Float)$/
-          || !($flags & B::SVf_POK) && ($flags & (B::SVf_IOK | B::SVf_NOK)))
-        && int($value) == $value;
+      return ref($value) =~ /^Math::Big(?:Int|Float)$/ && $value->is_int
+        || !($flags & B::SVf_POK) && ($flags & (B::SVf_IOK | B::SVf_NOK)) && int($value) == $value;
     }
   }
 
@@ -361,7 +360,7 @@ JSON::Schema::Modern::Utilities - Internal utilities for JSON::Schema::Modern
 
 =head1 VERSION
 
-version 0.536
+version 0.537
 
 =head1 SYNOPSIS
 
